You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ambari.apache.org by nc...@apache.org on 2015/12/01 19:19:56 UTC

[06/50] ambari git commit: AMBARI-14096. HostCleanup.py is removing system CentOS repositories (aonishuk)

AMBARI-14096. HostCleanup.py is removing system CentOS repositories (aonishuk)


Project: http://git-wip-us.apache.org/repos/asf/ambari/repo
Commit: http://git-wip-us.apache.org/repos/asf/ambari/commit/00cb7bad
Tree: http://git-wip-us.apache.org/repos/asf/ambari/tree/00cb7bad
Diff: http://git-wip-us.apache.org/repos/asf/ambari/diff/00cb7bad

Branch: refs/heads/branch-dev-patch-upgrade
Commit: 00cb7bad7666fd86a0bec332928a42f58a656707
Parents: b470e3e
Author: Andrew Onishuk <ao...@hortonworks.com>
Authored: Fri Nov 27 14:37:02 2015 +0200
Committer: Andrew Onishuk <ao...@hortonworks.com>
Committed: Fri Nov 27 14:37:02 2015 +0200

----------------------------------------------------------------------
 .../src/main/resources/custom_actions/scripts/check_host.py  | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ambari/blob/00cb7bad/ambari-server/src/main/resources/custom_actions/scripts/check_host.py
----------------------------------------------------------------------
diff --git a/ambari-server/src/main/resources/custom_actions/scripts/check_host.py b/ambari-server/src/main/resources/custom_actions/scripts/check_host.py
index 8b49725..01d79fe 100644
--- a/ambari-server/src/main/resources/custom_actions/scripts/check_host.py
+++ b/ambari-server/src/main/resources/custom_actions/scripts/check_host.py
@@ -77,12 +77,12 @@ THP_FILE_REDHAT = "/sys/kernel/mm/redhat_transparent_hugepage/enabled"
 THP_FILE_UBUNTU = "/sys/kernel/mm/transparent_hugepage/enabled"
 
 class CheckHost(Script):
   # Packages that are used to find repos (then repos are used to find other packages)
   PACKAGES = [
     "hadoop", "zookeeper", "webhcat", "oozie", "ambari", "*-manager-server-db",
     "*-manager-daemons", "mahout", "spark", "falcon", "hbase", "kafka", "knox",
-    "slider", "sqoop", "storm", "pig", "flume","hcatalog", "phoenix", "ranger",
-    "accumulo", "hive_*"
+    "slider", "sqoop", "storm", "flume","hcatalog", "phoenix", "ranger", "accumulo", "hive_*",
+    "pig_", "pig-", "pig." # there's a default 'pigz' package which we should avoid
   ]
   
 
@@ -106,7 +106,7 @@ class CheckHost(Script):
   
   # ignore repos from the list of repos to be cleaned
   IGNORE_REPOS = [
-    "HDP-UTILS", "AMBARI", "BASE"
+    "HDP-UTILS", "AMBARI", "BASE", "EXTRAS"
   ]
   
   def __init__(self):
@@ -77,12 +77,12 @@ THP_FILE_REDHAT = "/sys/kernel/mm/redhat_transparent_hugepage/enabled"
 
 class CheckHost(Script):
-  # Packages that are used to find repos (then repos are used to find other packages)
+  # Package prefixes that are used to find repos (then repos are used to find other packages)
   PACKAGES = [
     "hadoop", "zookeeper", "webhcat", "oozie", "ambari", "*-manager-server-db",